package com.weaver.seconddev.jcldoor.cmd;

import com.weaver.common.base.entity.result.WeaResult;
import com.weaver.framework.rpc.annotation.RpcReference;
import com.weaver.seconddev.jcldoor.util.DatabaseUtils;
import com.weaver.teams.domain.user.SimpleEmployee;
import com.weaver.teams.security.context.UserContext;
import com.weaver.workflow.common.constant.list.listdimension.RequestListInitDimensionTabEnum;
import com.weaver.workflow.common.entity.list.api.RequestListConditionApiEntity;
import com.weaver.workflow.common.entity.list.api.publicapi.RequestCountInfoPAEntity;
import com.weaver.workflow.list.api.rest.publicapi.WflRequestListRest;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletRequest;
import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.LocalTime;
import java.time.format.DateTimeFormatter;
import java.time.temporal.TemporalAdjusters;
import java.util.*;

/**
 * 开发人员综合信息
 *
 * @author wangj
 * @version 1.00版本
 * @Date 2024/3/14
 */
@Component
public class DevCollaborationInfoCmd {
    //日志
    private final static Logger log = LoggerFactory.getLogger(DevCollaborationInfoCmd.class);

    @Autowired
    private DatabaseUtils databaseUtils;

    public String tenant_key = "t7akvdnf84";

    @RpcReference(group = "workflow")
    WflRequestListRest wflRequestListRest;

    public Map<String, Object> getInfo(HttpServletRequest request, SimpleEmployee simpleEmployee) {
        Map<String, Object> dataMap = new HashMap<String, Object>();
        String startday = request.getParameter("startday");
        String endday = request.getParameter("endday");
        String employeeId = request.getParameter("employeeId");

        Map<String, Object> rtMap = getDaysInfo(startday, endday, employeeId);
        String rtcount = (String) rtMap.get("count");

        Map<String, Object> wtMap = getQuestInfo(startday, endday, employeeId);
        String wtcount = (String) wtMap.get("count");

        Map<String, Object> gtxzMap = getInteractInfo(startday, endday, employeeId);
        int gtxz = (int) gtxzMap.get("count");

        Map<String, Object> wfMap = getWfInfo(startday, endday);
        Long lccl = (Long) wfMap.get("count");

        dataMap.put("rtcount", rtcount);
        dataMap.put("wtcount", wtcount);
        dataMap.put("gtxz", gtxz);
        dataMap.put("lccl", lccl);
        return dataMap;
    }

    public Map<String, Object> getDaysInfo(String startday, String endday, String employeeId) {
        log.error("DevDaysCountCmd");
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");

        String groupId = "weaver-workflow-report-serviceworkflowreport";
        String sourceType = "LOGIC";

        Map<String, Object> dataMap = new HashMap<String, Object>();
        String devcou = "0";
        try {

            Calendar calendar = Calendar.getInstance();
            int year = calendar.get(Calendar.YEAR);

            if (StringUtils.isBlank(startday)) {
                startday = year + "-01-01";
            }
            if (StringUtils.isBlank(endday)) {
                endday = sdf.format(new Date());
            }

            if (StringUtils.isBlank(employeeId)) {
                employeeId = String.valueOf(UserContext.getCurrentEmployeeId());
            }

            if (StringUtils.isNotBlank(employeeId)) {
                String dataSql = " select count(1) as devcou \n" +
                        " from wfc_form_data l\n" +
                        " inner join fto_83 d on d.id = l.dataid\n" +
                        " inner join wfc_requestbase p on p.requestid = l.requestid\n" +
                        " where d.mutiresource='" + employeeId + "'\n" +
                        " and d.xsjfrq >='" + startday + "'" +
                        " and d.xsjfrq <='" + endday + "'" +
                        " and d.tenant_key='" + tenant_key + "'\n" +
                        " and d.is_delete='0'\n" +
                        " and l.tenant_key='" + tenant_key + "'\n" +
                        " and l.delete_type=0\n" +
                        " and p.tenant_key='" + tenant_key + "'\n" +
                        " and p.delete_type=0\n" +
                        " order by d.id desc ";

                log.info("DevDaysCountCmd sql:" + dataSql);

                Map<String, Object> result = databaseUtils.execute(sourceType, groupId, dataSql);
                List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(result);
                if (CollectionUtils.isNotEmpty(recordList)) {
                    devcou = String.valueOf(recordList.get(0).get("devcou"));
                }
            }
            dataMap.put("count", devcou);
        } catch (Exception e) {
            log.error("DevDaysCountCmd-Exception:" + e);
        }
        return dataMap;
    }

    public Map<String, Object> getQuestInfo(String startday, String endday, String employeeId) {
        log.error("DevQuestCountCmd");
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");

        String groupId = "weaver-workflow-report-serviceworkflowreport";
        String sourceType = "LOGIC";


        Map<String, Object> dataMap = new HashMap<String, Object>();
        String devcou = "0";
        try {

            Calendar calendar = Calendar.getInstance();
            int year = calendar.get(Calendar.YEAR);

            if (StringUtils.isBlank(startday)) {
                startday = year + "-01-01";
            }
            if (StringUtils.isBlank(endday)) {
                endday = sdf.format(new Date());
            }

            if (StringUtils.isBlank(employeeId)) {
                employeeId = String.valueOf(UserContext.getCurrentEmployeeId());
            }

            if (StringUtils.isNotBlank(employeeId)) {
                String dataSql = " select ifnull(sum(d.integer2),0) as devcou \n" +
                        " from wfc_form_data l\n" +
                        " inner join fto_62 d on d.id = l.dataid\n" +
                        " inner join wfc_requestbase p on p.requestid = l.requestid\n" +
                        " where d.multiresource5='" + employeeId + "'\n" +
                        " and d.date2 >='" + startday + "'" +
                        " and d.date2 <='" + endday + "'" +
                        " and d.tenant_key='" + tenant_key + "'\n" +
                        " and d.is_delete='0'\n" +
                        " and l.tenant_key='" + tenant_key + "'\n" +
                        " and l.delete_type=0\n" +
                        " and p.tenant_key='" + tenant_key + "'\n" +
                        " and p.delete_type=0\n" +
                        " order by d.id desc ";

                log.info("DevQuestCountCmd dataSql:" + dataSql);

                Map<String, Object> result = databaseUtils.execute(sourceType, groupId, dataSql);
                List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(result);
                if (CollectionUtils.isNotEmpty(recordList)) {
                    devcou = String.valueOf(recordList.get(0).get("devcou"));
                }
            }
            dataMap.put("count", devcou);
        } catch (Exception e) {
            log.error("DevQuestCountCmd-Exception:" + e);
        }
        return dataMap;
    }

    /**
     * 本年沟通协作数
     *
     * @param
     * @return
     */
    public Map<String, Object> getInteractInfo(String startday, String endday, String employeeId) {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");

        String groupId = "weaver-cowork-service";
        String sourceType = "LOGIC";

        Map<String,Object> dataMap = new HashMap<String,Object>();
        try{

            Calendar calendar = Calendar.getInstance();
            int year = calendar.get(Calendar.YEAR);

            if(StringUtils.isBlank(startday)){
                startday = year+"-01-01";
            }
            if(StringUtils.isBlank(endday)){
                endday = sdf.format(new Date());
            }

            if(StringUtils.isBlank(employeeId)){
                employeeId = String.valueOf(UserContext.getCurrentEmployeeId());
            }

            String sql = " select count(1) as count from cw_content " +
                    " where  CREATOR='"+employeeId+"'\n" +
                    " and left(CREATE_TIME,10)>='"+startday+"' and left(CREATE_TIME,10) <= '"+endday+"'" ;

            log.error("getInteractInfo sql:"+sql);
            Map<String, Object> result = databaseUtils.execute(sourceType, groupId, sql);
            List<Map<String,Object>> recordList = databaseUtils.getDataSourceList(result);
            if(recordList.size()>0){
                dataMap = recordList.get(0);
            }

        }catch (Exception e){
            log.error("getInteractInfo-Exception:"+e.getMessage());
        }
        return dataMap;
    }


    /**
     * 本年流程处理数量
     *
     * @param
     * @return
     */
    public Map<String, Object> getWfInfo(String startday, String endday) {
        log.error("PortalWfDealCountCmd");
        Map<String, Object> data = new HashMap<>(100);
        DateTimeFormatter format = DateTimeFormatter.ofPattern("yyyy-MM-dd");

        Long count = 0L;
        try {
            RequestListConditionApiEntity conditionEntity = new RequestListConditionApiEntity();
            SimpleEmployee employee = UserContext.getCurrentUser();
            LocalDateTime startDateTime = LocalDateTime.of(LocalDate.from(LocalDateTime.now().with(TemporalAdjusters.firstDayOfYear())), LocalTime.MIN);
            if (StringUtils.isNotBlank(startday)) {
                startDateTime = LocalDateTime.parse(startday, format);
            }

            LocalDateTime endDateTime = LocalDateTime.now();
            if (StringUtils.isNotBlank(endday)) {
                endDateTime = LocalDateTime.parse(endday, format);
            }
            conditionEntity.setCusOperateDateStart(startDateTime);
            conditionEntity.setCusOperateDateEnd(endDateTime);

            WeaResult<RequestCountInfoPAEntity> RequestCountInfoPAEntity = wflRequestListRest.getRequestCountByTabId(employee, RequestListInitDimensionTabEnum.DONE_FLOWALL.getTabid(), conditionEntity);
            int code = RequestCountInfoPAEntity.getCode();
            if (code == 200) {
                count = RequestCountInfoPAEntity.getData().getCount();
            }

        } catch (Exception e) {
            log.error("PortalWfDealCountCmd-Exception:" + e);

        }
        data.put("count", count);
        return data;
    }
}
