package com.weaver.seconddev.jcldoor.cmd;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;

import com.weaver.seconddev.jcldoor.util.CommonUtils;
import com.weaver.seconddev.jcldoor.util.DatabaseUtils;
import com.weaver.teams.domain.user.SimpleEmployee;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import javax.servlet.http.HttpServletRequest;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 生日祝福
 *
 * @author wangj
 * @version 1.00版本
 * @Date 2024/3/5
 * @desc 由于用户信息表中没有找到生日字段，通过系统标准接口获取生日祝福信息
 */
@Component
public class PortalBirthdayWishesCmd {
    //日志
    private final static Logger log = LoggerFactory.getLogger(PortalBirthdayWishesCmd.class);

    @Autowired
    private DatabaseUtils databaseUtils;

    /**
     * 获取生日祝福信息
     * @param simpleEmployee
     * @return
     */
    public Map<String, Object> getInfo(HttpServletRequest request, SimpleEmployee simpleEmployee) {
        Map<String, Object> result = new HashMap<>(100);
        JSONArray list = new JSONArray();

        try {
            String groupId = "weaver-hr-service";
            String sourceType = "LOGIC";
            String tenant_key = "t7akvdnf84";


            SimpleDateFormat sdf = new SimpleDateFormat("MM-dd");
            Date date = new Date();
            String day = sdf.format(date);

            if (StringUtils.isNotBlank(day)) {
                String dataSql = "select\n" +
                        "  k.id,\n" +
                        "  k.sex,\n" +
                        "  k.username,\n" +
                        "  right(left(BIRTHDAY, 10), 5) as BIRTHDAY,\n" +
                        "  b.name as department,\n" +
                        "  d.name as subcompany,\n" +
                        "  c.name as position\n" +
                        "from\n" +
                        "  hr_userinfo t\n" +
                        "  inner join eteams.employee k on k.id = t.user\n" +
                        "  inner join eteams.department b on k.department = b.id\n" +
                        "  inner join eteams.department d on b.subcompanyid = d.id\n" +
                        "  inner join eteams.position c on c.id = k.position\n" +
                        "where\n" +
                        "  BIRTHDAY is not null\n" +
                        "  and right(left(BIRTHDAY, 10), 5) = '"+day+"'\n" +
                        "  and k.status = 'normal'\n" +
                        "  and k.type = 'inside'\n" +
                        "  and k.tenant_key = '" + tenant_key + "'";

                log.error("getuserIfo--dataSql:" + dataSql);
                Map<String, Object> data = databaseUtils.execute(sourceType, groupId, dataSql);
                List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(data);
                if (CollectionUtils.isNotEmpty(recordList)) {
                    for(Map<String, Object> map:recordList){
                        String id = CommonUtils.null2String(map.get("id"));
                        String sextype = CommonUtils.null2String(map.get("sex"));
                        int sex = parseSex(sextype);
                        String username = CommonUtils.null2String(map.get("username"));
                        String department = CommonUtils.null2String(map.get("department"));
                        String subcompany = CommonUtils.null2String(map.get("subcompany"));
                        String position = CommonUtils.null2String(map.get("position"));

                        JSONObject obj = new JSONObject();
                        obj.put("id",id);
                        obj.put("sex",sex);
                        obj.put("username",username);
                        obj.put("department",department);
                        obj.put("subcompany",subcompany);
                        obj.put("position",position);
                        list.add(obj);
                    }
                }

            }
        } catch (Exception e) {
            log.error("PortalBirthdayWishesCmd--Exception:" + e.getMessage());
        }

        result.put("list",list);
        return result;
    }


    /**
     * 转换性别类型
     * @param sextype
     * @return
     */
    private int parseSex(String sextype){
        //0：男 1：女
        int sex = 0;
        switch (sextype){
            case "male":
                sex = 0;
                break;
            case "female":
                sex = 1;
                break;
            default:
                sex = 0;
                break;
        }

        return sex;
    }
}
