package com.weaver.seconddev.jcldoor.cmd;

import com.weaver.seconddev.jcldoor.util.DatabaseUtils;
import com.weaver.teams.domain.user.SimpleEmployee;
import com.weaver.teams.security.context.UserContext;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletRequest;
import java.time.LocalDate;
import java.time.Month;
import java.time.YearMonth;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 绩效信息
 *
 * @author wangj
 * @version 1.00版本
 * @Date 2024/3/8
 */
@Component
public class PortalPerformanceInfoCmd {
    //日志
    private final static Logger log = LoggerFactory.getLogger(PortalPerformanceInfoCmd.class);

    @Autowired
    private DatabaseUtils databaseUtils;

    public String tenant_key = "t7akvdnf84" ;

    public Map<String, Object> getInfo(HttpServletRequest request, SimpleEmployee simpleEmployee) {
        Map<String,Object> dataMap = new HashMap<String,Object>(100);
        try {

            String employeeId = request.getParameter("employeeId");
            LocalDate currentDate = LocalDate.now();
            LocalDate lastMonthDate = currentDate.minusMonths(1);
            int lastMonth = lastMonthDate.getMonthValue();

            if(StringUtils.isBlank(employeeId)){
                employeeId = String.valueOf(UserContext.getCurrentEmployeeId());
            }

            String groupId = "weaver-ebuilder-form-service";
            String sourceType = "LOGIC";

            Map<String, Object> scoreMap = getLastMonthKpi2(employeeId,groupId,sourceType);

            List<Map<String, String>> yearList = getWholeYearKpi2(employeeId,groupId,sourceType);

            dataMap.put("scoreMap",scoreMap);
            dataMap.put("yearList",yearList);

        } catch (Exception e) {
            e.printStackTrace();
            log.error("PortalPerformanceInfoCmd :"+e);
            dataMap.put("count","-1");
        }

        return dataMap;
    }

    public Map<String, Object> getLastMonthKpi2(String employeeId, String groupId, String sourceType){

        log.error("PortalPerformanceInfoCmd getLastMonthKpi2");

        Map<String, Object> dataMap = new HashMap<String,Object>();

        List<Map<String,Object>> indicatorList = new ArrayList<Map<String,Object>>();

        if(StringUtils.isNotBlank(employeeId)){
            String sql =" select left(k.real_period,10) as real_period,left(k.real_period,7) as period_month,k.kpi_scheme,k.score\n" +
                    " from (select real_period,kpi_scheme,score\n" +
                    "       from hr_kpi_flow  \n" +
                    "       where kpi_user='"+employeeId+"'  \n" +
                    "       and module = 'kpiFlow' \n" +
                    "       and date_type = 'month' \n" +
                    "       and delete_type = '0' " +
                    "       and tenant_key='"+tenant_key+"'\n" +
                    "       and FLOW_STATUS in('noApprove','approve','finished')\n" +
                    "       order by real_period desc\n" +
                    ") k  limit 1 ";

            log.error("sql20-1:"+sql);
            Map<String, Object> result = databaseUtils.execute(sourceType, groupId, sql);
            List<Map<String,Object>> recordList = databaseUtils.getDataSourceList(result);
            if(CollectionUtils.isNotEmpty(recordList)){
                Map<String,Object> recordMap = recordList.get(0);
                if(!recordMap.isEmpty()){
                    String score = String.valueOf(recordMap.get("score"));
                    String kpi_scheme = String.valueOf(recordMap.get("kpi_scheme"));
                    String real_period = String.valueOf(recordMap.get("real_period"));
                    String period_month = String.valueOf(recordMap.get("period_month"));

                    dataMap.put("score",score);
                    dataMap.put("yearmonth",period_month);
                    dataMap.put("kpi_scheme",kpi_scheme);
                    dataMap.put("real_period",real_period);
                }
            }
        }

        if(!dataMap.isEmpty()){
            String kpi_scheme = String.valueOf(dataMap.get("kpi_scheme"));

            log.error("kpi_scheme:"+kpi_scheme);

            if(StringUtils.isNotBlank(kpi_scheme)){
                String sql =" select indicator_type,indicator_description,weight \n" +
                        " from hr_kpi_scheme_indicator " +
                        " where scheme_id='"+kpi_scheme+"' " +
                        " and indicator_mode='quantify'\n" +
                        " and status='on' " +
                        " and delete_type = '0'" +
                        " and tenant_key = '"+tenant_key+"'" ;

                log.error("sql2:"+sql);
                Map<String, Object> result = databaseUtils.execute(sourceType, groupId, sql);
                List<Map<String,Object>> recordList = databaseUtils.getDataSourceList(result);

                log.error("recordList:"+recordList.size());

                if(recordList.size()>=2){
                    for(int i=0;i<2;i++){
                        indicatorList.add(recordList.get(i));
                    }
                }else if(recordList.size() == 1){
                    indicatorList.add(recordList.get(0));

                    Map<String, Object> indicatorMap = new HashMap<String, Object>();
                    sql =   " select name,data_row,property\n" +
                            " from hr_kpi_details_link\n" +
                            " where kpi_details in( " +
                            "           select id\n" +
                            "           from hr_kpi_details " +
                            "           where KPI_SCHEME='"+kpi_scheme+"'\n" +
                            "           and MODULE='kpiSchemeSetting'\n" +
                            "           and TENANT_KEY='"+tenant_key+"'\n" +
                            "           and DELETE_TYPE = 0" +
                            "        )\n" +
                            "    and module = 'kpiSchemeSetting'\n" +
                            "    and tenant_key = '"+tenant_key+"'\n" +
                            "    and delete_type = '0'\n" +
                            "    and property in('weight', 'describe', 'type')\n" +
                            "    and data_row in ( \n" +
                            "        select p.data_row from (\n" +
                            "            select w.data_row from (\n" +
                            "                select data_row \n" +
                            "                from hr_kpi_details_link\n" +
                            "                where kpi_details in ( " +
                            "                       select id\n" +
                            "                       from hr_kpi_details " +
                            "                       where KPI_SCHEME='"+kpi_scheme+"'\n" +
                            "                       and MODULE='kpiSchemeSetting'\n" +
                            "                       and TENANT_KEY='"+tenant_key+"'\n" +
                            "                       and DELETE_TYPE = 0" +
                            "                 )\n" +
                            "                    and PROPERTY = 'weight'\n" +
                            "                    and MODULE = 'kpiSchemeSetting'\n" +
                            "                    and TENANT_KEY = '"+tenant_key+"'\n" +
                            "                    and DELETE_TYPE = '0'\n" +
                            "                    order by name desc\n" +
                            "            ) w limit 1 \n" +
                            "        ) p\n" +
                            "    )";
                    log.error("sql3:"+sql);
                    Map<String, Object> result2 = databaseUtils.execute(sourceType, groupId, sql);
                    List<Map<String,Object>> recordList2 = databaseUtils.getDataSourceList(result2);
                    log.error("recordList2:"+recordList2.size());
                    for(int i=0;i<recordList2.size();i++){
                        Map<String,Object> recordMap = recordList2.get(i);
                        String name = String.valueOf(recordMap.get("name"));
                        String property = String.valueOf(recordMap.get("property"));

                        log.error("name:"+name);
                        log.error("property:"+property);

                        if("weight".equalsIgnoreCase(property)){
                            indicatorMap.put("weight",name);
                        }
                        if("describe".equalsIgnoreCase(property)){
                            indicatorMap.put("indicator_description",name);
                        }
                        if("type".equalsIgnoreCase(property)){
                            indicatorMap.put("indicator_type",name);
                        }
                    }

                    if(!indicatorMap.isEmpty()){
                        indicatorList.add(indicatorMap);
                    }

                }else{

                    sql =   "  select w.data_row from (\n" +
                            "    select data_row\n" +
                            "    from hr_kpi_details_link\n" +
                            "    where kpi_details in( " +
                            "           select id\n" +
                            "           from hr_kpi_details " +
                            "           where KPI_SCHEME='"+kpi_scheme+"'\n" +
                            "           and MODULE='kpiSchemeSetting'\n" +
                            "           and TENANT_KEY='"+tenant_key+"'\n" +
                            "           and DELETE_TYPE = 0" +
                            "        )\n" +
                            "        and PROPERTY = 'weight'\n" +
                            "        and MODULE = 'kpiSchemeSetting'\n" +
                            "        and TENANT_KEY = '"+tenant_key+"'\n" +
                            "        and DELETE_TYPE = '0'\n" +
                            "    order by name desc\n" +
                            ") w  limit 2" ;
                    log.error("sql4:"+sql);
                    Map<String, Object> result3 = databaseUtils.execute(sourceType, groupId, sql);
                    List<Map<String,Object>> recordList3 = databaseUtils.getDataSourceList(result3);
                    for(int k=0;k<recordList3.size();k++){
                        Map<String,Object> recordMap3 = recordList3.get(k);

                        String data_row = String.valueOf(recordMap3.get("data_row"));

                        Map<String, Object> indicatorMap = new HashMap<String, Object>();

                        sql =   " select name,data_row,property\n" +
                                " from hr_kpi_details_link\n" +
                                " where kpi_details in( " +
                                "           select id\n" +
                                "           from hr_kpi_details " +
                                "           where KPI_SCHEME='"+kpi_scheme+"'\n" +
                                "           and MODULE='kpiSchemeSetting'\n" +
                                "           and TENANT_KEY='"+tenant_key+"'\n" +
                                "           and DELETE_TYPE = 0" +
                                "    )\n" +
                                "    and MODULE = 'kpiSchemeSetting'\n" +
                                "    and TENANT_KEY = '"+tenant_key+"'\n" +
                                "    and DELETE_TYPE = '0'\n" +
                                "    and property in('weight', 'describe', 'type')\n" +
                                "    and data_row in("+data_row+")" ;

                        log.error("sql5:"+sql);

                        Map<String, Object> result2 = databaseUtils.execute(sourceType, groupId, sql);
                        List<Map<String,Object>> recordList2 = databaseUtils.getDataSourceList(result2);

                        for(int i=0;i<recordList2.size();i++){

                            Map<String,Object> recordMap = recordList2.get(i);

                            String name = String.valueOf(recordMap.get("name"));
                            String property = String.valueOf(recordMap.get("property"));
                            if("weight".equalsIgnoreCase(property)){
                                indicatorMap.put("weight",name);
                            }
                            if("describe".equalsIgnoreCase(property)){
                                indicatorMap.put("indicator_description",name);
                            }
                            if("type".equalsIgnoreCase(property)){
                                indicatorMap.put("indicator_type",name);
                            }
                        }

                        indicatorList.add(indicatorMap);
                    }
                }
            }
            dataMap.put("indicator",indicatorList);
        }
        return dataMap ;
    }


    public List<Map<String, String>> getWholeYearKpi2(String employeeId,String groupId,String sourceType){

        List<Map<String, String>> dateList = new ArrayList<Map<String, String>>();

        Map<String, String> dataMap = null;
        LocalDate localDate = LocalDate.now();
        int year = localDate.getYear() ;
        int dayOfYear = 1 ;
        String[] monthzw = new String[]{"一月","二月","三月","四月","五月","六月","七月","八月","九月","十月","十一月","十二月"};

        for(int i=1;i<=12;i++){
            Month month = Month.of(i);
            LocalDate startDay = YearMonth.of(year, month).atDay(dayOfYear); // 计算当前月份的首日
            LocalDate endDay = YearMonth.of(year, month).atEndOfMonth(); // 计算当前月份的最后一天

            log.error("getWholeYearKpi2-startDay:"+startDay);
            log.error("getWholeYearKpi2-endDay:"+endDay);

            String yearMonth = "";
            if(monthzw.length==12){
                yearMonth = monthzw[i-1];
            }

            String sql =" select score from hr_kpi_flow " +
                    " where kpi_user='"+employeeId+"' " +
                    " and left(real_period,10) >= '" +startDay+"'" +
                    " and left(real_period,10) <='" + endDay +"'" +
                    " and module = 'kpiFlow'" +
                    " and date_type = 'month'" +
                    " and flow_status in('noApprove','approve','finished') \n" +
                    " and delete_type = '0'" +
                    " and tenant_key='"+tenant_key+"' " ;

            log.error("getWholeYearKpi2-sql:"+sql);

            dataMap = new HashMap<String,String>();

            Map<String, Object> result = databaseUtils.execute(sourceType, groupId, sql);
            List<Map<String,Object>> recordList = databaseUtils.getDataSourceList(result);
            if(CollectionUtils.isNotEmpty(recordList)){
                Map<String,Object> recordMap = recordList.get(0);
                if(!recordMap.isEmpty()){
                    String score = String.valueOf(recordMap.get("score"));
                    if(StringUtils.isNotBlank(score)){
                        dataMap.put(yearMonth,score);
                    }
                }
            }else{
                dataMap.put(yearMonth,"0");
            }

            dateList.add(dataMap);
        }
        return dateList ;
    }



    public static String null2String(String s,String def) {
        return s == null ?(def==null?"":def) : s;

    }
}
