package com.weaver.seconddev.jcldoor.cmd;

import com.weaver.common.base.entity.result.WeaResult;
import com.weaver.framework.rpc.annotation.RpcReference;
import com.weaver.seconddev.jcldoor.util.DatabaseUtils;
import com.weaver.teams.domain.user.SimpleEmployee;
import com.weaver.teams.security.context.UserContext;
import com.weaver.workflow.common.constant.list.listdimension.RequestListInitDimensionTabEnum;
import com.weaver.workflow.common.entity.list.api.RequestListConditionApiEntity;
import com.weaver.workflow.common.entity.list.api.publicapi.RequestCountInfoPAEntity;
import com.weaver.workflow.list.api.rest.publicapi.WflRequestListRest;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletRequest;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.LocalTime;
import java.time.format.DateTimeFormatter;
import java.time.temporal.TemporalAdjusters;
import java.util.HashMap;
import java.util.Map;

/**
 * 本年流程处理数量
 *
 * @author wangj
 * @version 1.00版本
 * @Date 2024/3/13
 */
@Component
public class PortalWfDealCountCmd {
    //日志
    private final static Logger log = LoggerFactory.getLogger(PortalWfDealCountCmd.class);

    @Autowired
    private DatabaseUtils databaseUtils;

    @RpcReference(group = "workflow")
    WflRequestListRest wflRequestListRest;

    /**
     * 本年流程处理数量
     * @param simpleEmployee
     * @return
     */
    public Map<String, Object> getInfo(HttpServletRequest request, SimpleEmployee simpleEmployee) {
        log.error("PortalWfDealCountCmd");
        Map<String,Object> data = new HashMap<>(100);
        String startday = request.getParameter("startday");
        String endday = request.getParameter("endday");
        DateTimeFormatter format = DateTimeFormatter.ofPattern("yyyy-MM-dd");

        Long count = 0L ;
        try{
            RequestListConditionApiEntity conditionEntity = new RequestListConditionApiEntity();
            SimpleEmployee employee = UserContext.getCurrentUser();
            LocalDateTime startDateTime = LocalDateTime.of(LocalDate.from(LocalDateTime.now().with(TemporalAdjusters.firstDayOfYear())), LocalTime.MIN);
            if(StringUtils.isNotBlank(startday)){
                startDateTime = LocalDateTime.parse(startday, format);
            }

            LocalDateTime endDateTime = LocalDateTime.now();
            if(StringUtils.isNotBlank(endday)){
                endDateTime = LocalDateTime.parse(endday, format);
            }
            conditionEntity.setCusOperateDateStart(startDateTime);
            conditionEntity.setCusOperateDateEnd(endDateTime);

            WeaResult<RequestCountInfoPAEntity> RequestCountInfoPAEntity = wflRequestListRest.getRequestCountByTabId(employee, RequestListInitDimensionTabEnum.DONE_FLOWALL.getTabid(), conditionEntity);
            int code = RequestCountInfoPAEntity.getCode();
            if(code == 200){
                count = RequestCountInfoPAEntity.getData().getCount();
            }

        }catch (Exception e){
            log.error("PortalWfDealCountCmd-Exception:"+e.getMessage());
        }
        data.put("count",count);
        return data;
    }

}
