package com.weaver.seconddev.jcldoor.cmd;

import com.weaver.common.base.entity.result.WeaResult;
import com.weaver.framework.rpc.annotation.RpcReference;
import com.weaver.seconddev.jcldoor.util.CommonUtils;
import com.weaver.seconddev.jcldoor.util.DatabaseUtils;
import com.weaver.teams.client.doc.remote.DocClientService;
import com.weaver.teams.domain.user.SimpleEmployee;
import com.weaver.teams.security.context.UserContext;
import com.weaver.workflow.common.constant.list.listdimension.RequestListInitDimensionTabEnum;
import com.weaver.workflow.common.entity.list.api.RequestListConditionApiEntity;
import com.weaver.workflow.common.entity.list.api.publicapi.RequestCountInfoPAEntity;
import com.weaver.workflow.list.api.rest.publicapi.WflRequestListRest;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 人员基本信息
 *
 * @author wangj
 * @version 1.00版本
 * @Date 2024/3/4
 */
@Component
public class UserInfoCmd {
    //日志
    private final static Logger log = LoggerFactory.getLogger(UserInfoCmd.class);

    @Autowired
    private DatabaseUtils databaseUtils;

    @RpcReference
    DocClientService docClientService;

    @RpcReference(group = "workflow")
    WflRequestListRest wflRequestListRest;

    /**
     * 我在泛微信息（姓名，部门-岗位，入职天数:478天，人员交流:80人，创建文档:128个，参与群聊:128个，创建流程:239条，处理流程:439条）
     *
     * @param simpleEmployee
     * @return
     */
    public Map<String, Object> getUserInfo(SimpleEmployee simpleEmployee) {
        Map<String, Object> map = new HashMap<>(100);
        String userid = String.valueOf(simpleEmployee.getEmployeeId());
        String username = String.valueOf(simpleEmployee.getName());
        String userimageurl = "/profile/" + userid + "/personal";
        String department = "";
        String position = "";
        int days = 0;
        String doccreate = "0";
        String wfcreate = "0";
        String wfdeal = "0";
        String cyqlsl = "0";
        String mtgtrs = "0";

        try {
            Map<String, Object> recordMap = new HashMap<String, Object>();
            String groupId = "weaver-ebuilder-form-service";
            String sourceType = "LOGIC";
            String tenant_key = "t7akvdnf84";

            if (StringUtils.isNotBlank(userid)) {
                String dataSql = "select   " +
                        "  a.id,   " +
                        "  a.username,   " +
                        "  a.hiredate,   " +
                        "  b.name as department,   " +
                        "  c.name as position   " +
                        "from   " +
                        "  eteams.employee a   " +
                        "  left join eteams.department b on a.department = b.id   " +
                        "  left join eteams.position c on c.id = a.position   " +
                        "where   " +
                        "  a.id = '" + userid + "'   " +
                        "  and a.tenant_key = '" + tenant_key + "'   " +
                        "  and a.status = 'normal'   " +
                        "  and a.type = 'inside'";

                log.error("getuserIfo--dataSql:" + dataSql);
                Map<String, Object> result = databaseUtils.execute(sourceType, groupId, dataSql);
                List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(result);
                if (CollectionUtils.isNotEmpty(recordList)) {
                    recordMap = recordList.get(0);
                }
                username = CommonUtils.null2String(recordMap.get("username"));
                department = CommonUtils.null2String(recordMap.get("department"));
                position = CommonUtils.null2String(recordMap.get("position"));
                String hiredate = CommonUtils.null2String(recordMap.get("hiredate"));
                if (!"".equals(hiredate)) {
                    days = calculateMinute(hiredate);
                }
                //文档创建
                doccreate = getDocCreateNum(userid);
                //流程创建
                wfcreate = getWfCreateNum();
                //流程处理
                wfdeal = getWfDealNum();

                //
                cyqlsl = "0";
                mtgtrs = "0";
            }
        } catch (Exception e) {
            log.error("getUserInfo--Exception:" + e.getMessage());
        }
        map.put("userid", userid);
        map.put("userimageurl",userimageurl);
        map.put("username", username);
        map.put("department", department);
        map.put("position", position);
        map.put("days", days);
        map.put("doccreate", doccreate);
        map.put("wfcreate", wfcreate);
        map.put("wfdeal", wfdeal);
        map.put("cyqlsl", cyqlsl);
        map.put("mtgtrs", mtgtrs);

        return map;
    }

    /**
     * 获取文档创建数量
     *
     * @param userid
     * @return
     */
    public String getDocCreateNum(String userid) {
        String num = "0";
        try {
            long employeeId = Long.parseLong(userid);
            int doccreatecount = docClientService.countByCreator(employeeId);
            num = doccreatecount + "";
        } catch (Exception e) {
            e.printStackTrace();
            log.error("getDocCreateNum:" + e);
        }
        return num;
    }

    /**
     * 流程创建数量
     *
     * @return
     */
    public String getWfCreateNum() {
        String num = "0";
        try {
            SimpleEmployee employee = UserContext.getCurrentUser();
            RequestListConditionApiEntity conditionEntity = new RequestListConditionApiEntity();
            WeaResult<RequestCountInfoPAEntity> RequestCountInfoPAEntity = wflRequestListRest.getRequestCountByTabId(employee, RequestListInitDimensionTabEnum.MINE_FLOWALL.getTabid(), conditionEntity);
            Long count = RequestCountInfoPAEntity.getData().getCount();
            num = count + "";
        } catch (Exception e) {
            e.printStackTrace();
            log.error("getWfCreateNum:" + e);
        }
        return num;
    }

    /**
     * 流程处理数量
     *
     * @return
     */
    public String getWfDealNum() {
        String num = "0";
        try {
            SimpleEmployee employee = UserContext.getCurrentUser();
            RequestListConditionApiEntity conditionEntity = new RequestListConditionApiEntity();
            WeaResult<RequestCountInfoPAEntity> RequestCountInfoPAEntity = wflRequestListRest.getRequestCountByTabId(employee, RequestListInitDimensionTabEnum.DONE_FLOWALL.getTabid(), conditionEntity);
            int code = RequestCountInfoPAEntity.getCode();
            Long count = RequestCountInfoPAEntity.getData().getCount();
            num = count + "";
        } catch (Exception e) {
            e.printStackTrace();
            log.error("getWfDealNum:" + e);
        }
        return num;
    }

    /**
     * 计算日期相差天数
     *
     * @param sdate
     * @return
     * @throws ParseException
     */
    public static int calculateMinute(String sdate) throws ParseException {
        long l = 0;
        boolean flag = isTimestampFormat(sdate);
        SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd");
        Date etime = new Date();
        if (flag) {
            Date stime = df.parse(sdate);
            l = etime.getTime() - stime.getTime();
        } else {
            l = etime.getTime() - new Long(sdate);
        }

        int day = (int) (l / (24 * 60 * 60 * 1000));

        return day;
    }

    public static boolean isTimestampFormat(String inputDate) {
        // 使用 simpleDateFormat 尝试将输入日期解析为时间戳格式
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        try {
            sdf.parse(inputDate);
            return true;
        } catch (Exception e) {
            return false;
        }
    }

}
