package com.weaver.seconddev.jcldoor.controller;

import com.weaver.common.authority.annotation.WeaPermission;
import com.weaver.common.base.entity.result.WeaResult;
import com.weaver.framework.rpc.annotation.RpcReference;
import com.weaver.seconddev.jcldoor.service.JucailinPortalService;
import com.weaver.seconddev.jcldoor.util.CommonUtils;
import com.weaver.teams.domain.user.SimpleEmployee;
import com.weaver.teams.security.context.UserContext;
import com.weaver.workflow.common.constant.list.listdimension.RequestListInitDimensionTabEnum;
import com.weaver.workflow.common.entity.list.api.RequestListConditionApiEntity;
import com.weaver.workflow.common.entity.list.api.publicapi.RequestCountInfoPAEntity;
import com.weaver.workflow.common.entity.list.api.publicapi.RequestListInfoPAEntity;
import com.weaver.workflow.list.api.rest.publicapi.WflRequestListRest;
import groovy.util.logging.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.text.SimpleDateFormat;
import java.util.*;


@Slf4j
@RestController
@RequestMapping("/api/secondev/njjucailin/portal")
public class JucailinPortalController {


    private final Logger log = LoggerFactory.getLogger(JucailinPortalController.class);

    @Autowired
    private JucailinPortalService jucailinPortalService;

    @RpcReference(group = "workflow")
    WflRequestListRest wflRequestListRest;

    /**
     * 人员基本信息接口
     * @param request
     * @return
     */
    @GetMapping("/getPortalUser")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPortalUser(HttpServletRequest request){
        log.error("getPortalUser");
        Map<String, Object> recordMap = new HashMap<String, Object>();
        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();

        try{
            recordMap = jucailinPortalService.getPortalUserData(simpleEmployee);
        }catch (Exception e){
            log.error("getPortalUser-Exception:"+e);
        }
        return WeaResult.success(recordMap);
    }

    /**
     *
     * @param request
     * @return
     */
    @GetMapping("/getPortalAttendance")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPortalAttendance(HttpServletRequest request){
        log.error("getPortalAttendance");

        Map<String, Object> recordMap = new HashMap<String, Object>();

        Long employeeId = UserContext.getCurrentEmployeeId();

        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();

        try{
            recordMap = jucailinPortalService.getPortalAttendanceData(simpleEmployee);
        }catch (Exception e){
            log.error("testSapi-Exception:"+e);
        }

        return WeaResult.success(recordMap);
    }


    @GetMapping("/getPortalPerformance")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPortalPerformance(HttpServletRequest request){
        log.error("getPortalPerformance");

        Map<String, Object> recordMap = new HashMap<String, Object>();

        Long employeeId = UserContext.getCurrentEmployeeId();

        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();

        try{
            recordMap = jucailinPortalService.getPortalPerformanceData(simpleEmployee);
        }catch (Exception e){
            log.error("testSapi-Exception:"+e);
        }

        return WeaResult.success(recordMap);
    }



    /**
     * 人员生日祝福
     * @param request
     * @return
     */
    @GetMapping("/getPortalBirthdayWishes")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPortalBirthdayWishes(HttpServletRequest request){
        log.error("getPortalBirthdayWishes");

        Map<String, Object> recordMap = new HashMap<String, Object>();

        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();

        try{
            recordMap = jucailinPortalService.getPortalBirthdayWishes(request,simpleEmployee);
        }catch (Exception e){
            log.error("getPortalBirthdayWishes-Exception:"+e);
        }

        return WeaResult.success(recordMap);
    }


    /**
     * 风险信息
     * @param request
     * @return
     */
    @GetMapping("/getPortalRiskInfo")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPortalRiskInfo(HttpServletRequest request){
        log.error("getPortalRiskInfo");

        Map<String, Object> recordMap = new HashMap<String, Object>();

        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();

        try{
            recordMap = jucailinPortalService.getPortalRiskInfo(request,simpleEmployee);
        }catch (Exception e){
            log.error("getPortalRiskInfo-Exception:"+e);
        }

        return WeaResult.success(recordMap);
    }


    /**
     * 绩效信息
     * @param request
     * @return
     */
    @GetMapping("/getPortalPerformanceInfo")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPortalPerformanceInfo(HttpServletRequest request){
        log.error("getPortalPerformanceInfo");

        Map<String, Object> recordMap = new HashMap<String, Object>();
        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();
        try{
            recordMap = jucailinPortalService.getPortalPerformanceInfo(request,simpleEmployee);
        }catch (Exception e){
            log.error("getPortalPerformanceInfo-Exception:"+e.getMessage());
        }

        return WeaResult.success(recordMap);
    }



    /**
     * 流程信息（我发起的）
     * @param request
     * @return
     */
    @GetMapping("/getWorkFlowInfo")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getWfInfoCreate(HttpServletRequest request){
        log.error("getWorkFlowInfo");

        List<RequestListInfoPAEntity> requestListInfoPAEntityList = new ArrayList<RequestListInfoPAEntity>();
        try{
            RequestListConditionApiEntity conditionEntity = new RequestListConditionApiEntity();
            SimpleEmployee employee = UserContext.getCurrentUser();
            String keyword = CommonUtils.null2String(request.getParameter("keyword"));
            if(!"".equals(keyword)){
                conditionEntity.setRequestname(keyword);
            }
            String type = CommonUtils.null2String(request.getParameter("type"),"0");
            int pageSize = CommonUtils.getIntValue(request.getParameter("pageSize"),10);
            int pageNo = CommonUtils.getIntValue(request.getParameter("pageNo"),1);
            // 0 我发起的； 1 我的待办； 2  我的已办
            if("0".equals(type)){
                WeaResult<List<RequestListInfoPAEntity>> requestResult = wflRequestListRest.getRequestListByTabId(employee, RequestListInitDimensionTabEnum.MINE_FLOWALL.getTabid(), pageNo, pageSize, conditionEntity);
                int code = requestResult.getCode();
                if(code == 200){
                    requestListInfoPAEntityList = requestResult.getData();
                }
            }else if("1".equals(type)){
                WeaResult<List<RequestListInfoPAEntity>> requestResult = wflRequestListRest.getRequestListByTabId(employee, RequestListInitDimensionTabEnum.TODO_FLOWALL.getTabid(), pageNo, pageSize, conditionEntity);

                int code = requestResult.getCode();
                if(code == 200){
                    requestListInfoPAEntityList = requestResult.getData();
                }

            }else if("2".equals(type)){
                WeaResult<List<RequestListInfoPAEntity>>  requestResult = wflRequestListRest.getRequestListByTabId(employee, RequestListInitDimensionTabEnum.DONE_FLOWALL.getTabid(), pageNo, pageSize, conditionEntity);

                int code = requestResult.getCode();
                if(code == 200){
                    requestListInfoPAEntityList = requestResult.getData();
                }
            }
        }catch (Exception e){
            log.error("getWorkFlowInfo-Exception:"+e.getMessage());
            return WeaResult.fail(500,"程序执行异常");
        }
        return WeaResult.success(requestListInfoPAEntityList);
    }

    /**
     * 流程信息（我发起的）数量
     * @param request
     * @return
     */
    @GetMapping("/getWorkFlowInfoCount")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getWorkFlowInfoCount(HttpServletRequest request){
        log.error("getWorkFlowInfoCount");

        RequestCountInfoPAEntity RequestCountInfoPAEntity = new RequestCountInfoPAEntity();
        try{
            RequestListConditionApiEntity conditionEntity = new RequestListConditionApiEntity();
            SimpleEmployee employee = UserContext.getCurrentUser();
            String keyword = CommonUtils.null2String(request.getParameter("keyword"));
            if(!"".equals(keyword)){
                conditionEntity.setRequestname(keyword);
            }
            String type = CommonUtils.null2String(request.getParameter("type"),"0");

            // 0 我发起的； 1 我的待办； 2  我的已办
            if("0".equals(type)){
                WeaResult<RequestCountInfoPAEntity>  requestResult = wflRequestListRest.getRequestCountByTabId(employee, RequestListInitDimensionTabEnum.MINE_FLOWALL.getTabid(), conditionEntity);

                int code = requestResult.getCode();
                if(code == 200){
                    RequestCountInfoPAEntity = requestResult.getData();
                }
            }else if("1".equals(type)){
                WeaResult<RequestCountInfoPAEntity>  requestResult = wflRequestListRest.getRequestCountByTabId(employee, RequestListInitDimensionTabEnum.TODO_FLOWALL.getTabid(), conditionEntity);

                int code = requestResult.getCode();
                if(code == 200){
                    RequestCountInfoPAEntity = requestResult.getData();
                }

            }else if("2".equals(type)){
                WeaResult<RequestCountInfoPAEntity>  requestResult = wflRequestListRest.getRequestCountByTabId(employee, RequestListInitDimensionTabEnum.DONE_FLOWALL.getTabid(), conditionEntity);

                int code = requestResult.getCode();
                if(code == 200){
                    RequestCountInfoPAEntity = requestResult.getData();
                }
            }
        }catch (Exception e){
            log.error("getWorkFlowInfoCount-Exception:"+e.getMessage());
            return WeaResult.fail(500,"程序执行异常");
        }
        return WeaResult.success(RequestCountInfoPAEntity);
    }

    /***
     * 本年沟通协作数
     * @param request
     * @return
     */
    @GetMapping("/getPortalInteractCount")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPortalInteractCount(HttpServletRequest request){
        log.error("getPortalInteractCount");

        Map<String, Object> recordMap = new HashMap<String, Object>();
        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();
        try{
            recordMap = jucailinPortalService.getPortalInteractCount(request,simpleEmployee);
        }catch (Exception e){
            log.error("getPortalInteractCount-Exception:"+e.getMessage());
        }

        return WeaResult.success(recordMap);
    }

    /***
     * 本年文档贡献数
     * @param request
     * @return
     */
    @GetMapping("/getPortalDocCreateCount")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPortalDocCreateCount(HttpServletRequest request){
        log.error("getPortalDocCreateCount");

        Map<String, Object> recordMap = new HashMap<String, Object>();
        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();
        try{
            recordMap = jucailinPortalService.getPortalDocCreateCount(request,simpleEmployee);
        }catch (Exception e){
            log.error("getPortalDocCreateCount-Exception:"+e.getMessage());
        }

        return WeaResult.success(recordMap);
    }


    /***
     * 本年流程处理数量
     * @param request
     * @return
     */
    @GetMapping("/getPortalWfDealCount")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPortalWfDealCount(HttpServletRequest request){
        log.error("getPortalWfDealCount");

        Map<String, Object> recordMap = new HashMap<String, Object>();
        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();
        try{
            recordMap = jucailinPortalService.getPortalWfDealCount(request,simpleEmployee);
        }catch (Exception e){
            log.error("getPortalWfDealCount-Exception:"+e.getMessage());
        }

        return WeaResult.success(recordMap);
    }

    /***
     * 本年日报数量
     * @param request
     * @return
     */
    @GetMapping("/getPortalDailyCount")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPortalDailyCount(HttpServletRequest request){
        log.error("getPortalDailyCount");

        Map<String, Object> recordMap = new HashMap<String, Object>();
        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();
        try{
            recordMap = jucailinPortalService.getPortalDailyCount(request,simpleEmployee);
        }catch (Exception e){
            log.error("getPortalDailyCount-Exception:"+e.getMessage());
        }

        return WeaResult.success(recordMap);
    }


    /***
     * 本年人员综合信息（沟通协作数+文档贡献度+处理流程数+微博数量）
     * @param request
     * @return
     */
    @GetMapping("/getPortalCollaborationInfo")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPortalCollaborationInfo(HttpServletRequest request){
        log.error("getPortalCollaborationInfo");

        Map<String, Object> recordMap = new HashMap<String, Object>();
        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();
        try{
            recordMap = jucailinPortalService.getPortalCollaborationInfo(request,simpleEmployee);
        }catch (Exception e){
            log.error("getPortalCollaborationInfo-Exception:"+e.getMessage());
        }

        return WeaResult.success(recordMap);
    }



    /***
     * 项目人员验收信息
     * @param request
     * @return
     */
    @GetMapping("/getPorojectAcceptanceInfo")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPorojectAcceptanceInfo(HttpServletRequest request){
        log.error("getPortalCollaborationInfo");

        Map<String, Object> recordMap = new HashMap<String, Object>();
        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();
        try{
            recordMap = jucailinPortalService.getProjectAcceptanceInfo(request,simpleEmployee);
        }catch (Exception e){
            log.error("getPorojectAcceptanceInfo-Exception:"+e.getMessage());
        }

        return WeaResult.success(recordMap);
    }


    /***
     * 项目人员收款信息
     * @param request
     * @return
     */
    @GetMapping("/getPorojectReceiptsInfo")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPorojectReceiptsInfo(HttpServletRequest request){
        log.error("getPorojectReceiptsInfo");

        Map<String, Object> recordMap = new HashMap<String, Object>();
        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();
        try{
            recordMap = jucailinPortalService.getProjectReceiptsInfo(request,simpleEmployee);
        }catch (Exception e){
            log.error("getPorojectReceiptsInfo-Exception:"+e.getMessage());
        }

        return WeaResult.success(recordMap);
    }


    /***
     * 项目人员综合信息（收款信息+验收信息）
     * @param request
     * @return
     */
    @GetMapping("/getPorojectCollaborationInfo")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPorojectCollaborationInfo(HttpServletRequest request){
        log.error("getPorojectCollaborationInfo");

        Map<String, Object> recordMap = new HashMap<String, Object>();
        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();
        try{
            recordMap = jucailinPortalService.getProjectCollaborationInfo(request,simpleEmployee);
        }catch (Exception e){
            log.error("getPorojectCollaborationInfo-Exception:"+e.getMessage());
        }

        return WeaResult.success(recordMap);
    }


    /***
     * 开发人员问题支持数量
     * @param request
     * @return
     */
    @GetMapping("/getDevQuestCount")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getDevQuestCount(HttpServletRequest request){
        log.error("getPorojectReceiptsInfo");

        Map<String, Object> recordMap = new HashMap<String, Object>();
        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();
        try{
            recordMap = jucailinPortalService.getDevQuestCount(request,simpleEmployee);
        }catch (Exception e){
            log.error("getDevQuestCount-Exception:"+e.getMessage());
        }

        return WeaResult.success(recordMap);
    }


    /***
     * 开发人员人员支持数量
     * @param request
     * @return
     */
    @GetMapping("/getDevDaysCount")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getDevDaysCount(HttpServletRequest request){
        log.error("getDevDaysCount");

        Map<String, Object> recordMap = new HashMap<String, Object>();
        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();
        try{
            recordMap = jucailinPortalService.getDevDaysCount(request,simpleEmployee);
        }catch (Exception e){
            log.error("getDevDaysCount-Exception:"+e.getMessage());
        }

        return WeaResult.success(recordMap);
    }


    /***
     * 开发人员综合信息
     * @param request
     * @return
     */
    @GetMapping("/getDevCollaborationInfo")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getDevCollaborationInfo(HttpServletRequest request){
        log.error("getDevCollaborationInfo");

        Map<String, Object> recordMap = new HashMap<String, Object>();
        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();
        try{
            recordMap = jucailinPortalService.getDevCollaborationInfo(request,simpleEmployee);
        }catch (Exception e){
            log.error("getDevCollaborationInfo-Exception:"+e.getMessage());
        }

        return WeaResult.success(recordMap);
    }








}
